@@ -493,14 +493,13 @@ function overcloud_pingtest {
 
     overcloudrc_check
 
-    version=`curl http://download.cirros-cloud.net/version/released`
-    cirros_latest=cirros-$version-x86_64-disk.img
-    if [ ! -e $OVERCLOUD_IMAGES_PATH/$cirros_latest ]; then
-        log "Overcloud pingtest, trying to download latest $cirros_latest"
-        curl -o $OVERCLOUD_IMAGES_PATH/$cirros_latest http://download.cirros-cloud.net/$version/$cirros_latest
+    IMAGE_PATH=$OVERCLOUD_IMAGES_PATH/fedora-user.qcow2
+    if [ ! -e $IMAGE_PATH ]; then
+        log "Overcloud pingtest, trying to download Fedora image"
+        curl -L -o $IMAGE_PATH http://cloud.fedoraproject.org/fedora-21.x86_64.qcow2
     fi
     log "Overcloud pingtest, uploading demo tenant image to glance"
-    glance image-create --progress --name pingtest_image --is-public True --disk-format qcow2 --container-format bare --file $OVERCLOUD_IMAGES_PATH/$cirros_latest
+    glance image-create --progress --name pingtest_image --is-public True --disk-format qcow2 --container-format bare --file $IMAGE_PATH
 
     log "Overcloud pingtest, creating demo tenant keypair and external network"
     if ! nova keypair-show default 2>/dev/null; then tripleo user-config; fi
@@ -517,22 +516,29 @@ function overcloud_pingtest {
     fi
     log "Overcloud pingtest, creating tenant-stack heat stack:"
     heat stack-create -f $TENANT_PINGTEST_TEMPLATE tenant-stack || exitval=1
-    if tripleo wait_for -w 180 -d 10 -s "CREATE_COMPLETE" -- "heat stack-list | grep tenant-stack"; then
+    if tripleo wait_for -w 360 -d 10 -s "CREATE_COMPLETE" -- "heat stack-list | grep tenant-stack"; then
         log "Overcloud pingtest, heat stack CREATE_COMPLETE";
 
         vm1_ip=`heat output-show tenant-stack server1_public_ip -F raw`
 
         log "Overcloud pingtest, trying to ping the floating IPs $vm1_ip"
 
-        if tripleo wait_for -w 180 -d 10 -s "bytes from $vm1_ip" -- "ping -c 1 $vm1_ip" ; then
+        if tripleo wait_for -w 360 -d 10 -s "bytes from $vm1_ip" -- "ping -c 1 $vm1_ip" ; then
             ping -c 1 $vm1_ip
             log "Overcloud pingtest, SUCCESS"
         else
             ping -c 1 $vm1_ip || :
+            nova show Server1 || :
+            nova service-list || :
+            neutron agent-list || :
+            nova console-log Server1 || :
             log "Overloud pingtest, FAIL"
             exitval=1
         fi
     else
+        heat stack-show tenant-stack || :
+        heat event-list tenant-stack || :
+        heat resource-list -n 5 tenant-stack || :
         log "Overcloud pingtest, failed to create heat stack, trying cleanup"
         exitval=1
     fi
